@@ -4,6 +4,8 @@ hipamAnthropom <- function(data,asw.tol=0,maxsplit=5,local.const=NULL,orness=0.7
  tree <- initialize.tree(data, maxsplit, orness, type, ah, verbose, ...)
  #Local hipam: 
  tree <- hipam.local(tree, data, asw.tol, maxsplit, local.const, orness, type, ah, verbose, ...)
+ tree$cases <- tree$medoids
+ tree$medoids <- NULL
  tree
 }
 
