@@ -3,7 +3,7 @@ projShapes <- function(clust, array3D, asig, prototypes){
   x <- array3D[, , asig == clust]
   
   if (length(dim(x)) != 3) {
-    stop("Please ensure that array3D has 3 dimensions.")
+    return(cat("Please ensure that array3D has 3 dimensions."))
   }else{
     out_proc <- shapes::procGPA(x, distances = TRUE, pcaoutput = TRUE)
     shapes::plotshapes(out_proc$rotated)
